@@ -6,18 +6,21 @@ Synopsis: Código baseado na planilha casing do Nakka, disponível em:
 Obetivo de transformar a planilha do excel em uma ferramenta em python.
 """
 def main():
+    #Chama os pacotes usados no programa
     import math
-    import matplotlib.pyplot
+   # import matplotlib.pyplot  #Necessário somente caso for construir o gráfico, entretanto o gráfico não é necessário
     from casing import materials
+   # import materials
     from datetime import datetime
 
-
+#Abertura do programa
     print("--Casing--")
-
+#Solicitação da inserção de dados
     print ("---Dimensões do invólucro e Fatores de design---")
     Do= float(input('Insira o diâmetro externo em mm: '))
     t= float(input('Insira a espessura da parede em mm: '))
 
+#Opção para escolher a entrada e, consequentemente, a saída
     print(" ")
     print("Para inserir, pressione:")
     print("0 para o valor do Fator de design de segurança ")
@@ -28,7 +31,7 @@ def main():
         Sd= float(input('Insira o Fator de design de segurança: '))
     elif op=="1":
         Su= float(input('Insira o Fator de segurança de ruptura: '))
-
+#Mostrar lista de materiais
     opcao=input("Deseja ver a lista de materiais? (S/N) ")
     if opcao=="S" or opcao=="s": 
         for materials.mec_propk, materials.mec_propv in materials.mec_prop.items():
@@ -37,7 +40,7 @@ def main():
         pass
     prop = input('Digite o tipo do material do invólucro: ')
     p=materials.mec_prop[prop]
-
+#Saída dos resultados
     print(" ")
     print("-------------------------")
     print("Material: ", prop)
@@ -74,18 +77,20 @@ def main():
     dc=((dD*math.pi))#*0.0254
     print("Variação da circunferência do invólucro: dc= ",'{:.6f}'.format(dc)," m")
 
-#Construção gráfico
+#Construção gráfico (de acordo com a planilha do Nakka)
+    '''
     matplotlib.pyplot.title('Fator de ruptura para cilindros pressurizados')
     matplotlib.pyplot.xlabel('Fty/Ftu')
     matplotlib.pyplot.ylabel('B')
     matplotlib.pyplot.plot([0.5, 0.6, 0.7, 0.8, 0.9, 1], [2.048, 1.735, 1.527, 1.379, 1.254, 1.153], color='g', marker='o')
     matplotlib.pyplot.axis([0.5, 1, 1, 2.2]) # [xmin, xmax, ymin, ymax]
     matplotlib.pyplot.show()
-
+    '''
+ 
+#construção do arquivo em txt com os valores
     data=datetime.now()
     datatxt=data.strftime('%d/%m/%Y %H:%M')
 
-#construção do arquivo em txt com os valores
     arquivo = open('casing_results.txt', 'a')
     arquivo.write('\n')
     arquivo.write(datatxt)
@@ -125,4 +130,7 @@ def main():
     arquivo.write('--------------------------------')
     arquivo.write('\n')
     arquivo.write(' ')
-    arquivo.close()
\ No newline at end of file
+    arquivo.close()
+
+#Chamando a definição que o código foi colocado    
+main()
\ No newline at end of file
